#!/usr/bin/perl

sub load_fnames {
	my ($path) = @_;

	opendir(DIR, $path);
	my (@all_fnames) = readdir(DIR);
	closedir(DIR);

	my %fnames;
	foreach (@all_fnames) {
		$fnames{$_} = 1 if ($_ =~ /^brackets.*\.txt/);
	}

	return %fnames;
}

sub join_path {
	my ($dname, $fname) = @_;

	$dname =~ tr/\\/\//;
	$dname =~ s/\/$//;
	return "$dname/$fname";
}

sub diff1 {
	my ($path1, $path2) = @_;

	open(BRA, $path1) || die "Failed to open: $path1\n";
	my @bra1 = <BRA>;
	close(BRA);

	open(BRA, $path2) || die "Failed to open: $path2\n";
	my @bra2 = <BRA>;
	close(BRA);

	return 1 if ($#bra1 != $#bra2);

	for (my $i = 0; $i <= $#bra1; $i++) {
		my $item1 = $bra1[$i];
		my $item2 = $bra2[$i];
		$item1 =~ s/\s*$//;
		$item2 =~ s/\s*$//;
		if ($item1 != $item2) {
			return 1;
		}
	}

	return 0;
}

sub main {
	my $dname1 = "./expected";
	my $dname2 = "./yours";
	my %fnames1 = &load_fnames($dname1);
	my %fnames2 = &load_fnames($dname2);

	my $status = 0;
	foreach (keys(%fnames1)) {
		if ($fnames2{$_} != 1) {
			print STDERR "File \"$_\" not found in \"$dname2\"\n";
			$status = 1;
		}
	}
	foreach (keys(%fnames2)) {
		if ($fnames1{$_} != 1) {
			print STDERR "File \"$_\" not found in \"$dname1\"\n";
			$status = 1;
		}
	}

	if ($status != 0) {
		print STDERR "differ\n";
		return $status;
	}

	foreach my $fname (keys(%fnames1)) {
		my $path1 = &join_path($dname1, $fname);
		my $path2 = &join_path($dname2, $fname);
		if (&diff1($path1, $path2)) {
			printf STDERR ("differ \"%s\" and \"%s\"\n", $path1, $path2);
			$status = 1;
		}
	}

	return $status;
}

&main;
